@@ -6,6 +6,8 @@ labelVars <- attr(dataADaMCDISCP01, "labelVars")
 dataLB <- dataADaMCDISCP01$ADLBC
 dataDM <- dataADaMCDISCP01$ADSL
 dataLB <- annotateData(dataLB, annotations = list(data = dataDM))
+# subset of the data for the example
+dataLB <- subset(dataLB, VISIT %in% c("SCREENING 1", "WEEK 2", "WEEK 8"))
 
 ## time profile
 
@@ -22,7 +24,7 @@ scatterplotClinData(
 )
 
 # with actual visit
-dataPlot$AVISIT <- with(dataPlot, reorder(AVISIT, AVISITN))
+dataPlot$AVISIT <- with(dataPlot, reorder(trimws(AVISIT), AVISITN))
 scatterplotClinData(
 	data = dataPlot, 
 	xVar = "AVISIT",
@@ -32,7 +34,13 @@ scatterplotClinData(
 	labelVars = labelVars
 )
 
+
+
+\dontrun{
+
 # add number of subjects below each visit
+	
+if (requireNamespace("inTextSummaryTable", quietly = TRUE)) {
 
 # compute number of subjects by visit
 summaryTable <- inTextSummaryTable::computeSummaryStatisticsTable(
@@ -53,19 +61,25 @@ scatterplotClinData(
 	labelVars = labelVars
 )
 
+}
+
+}
 
 ## pairwise comparison plot of two parameters of interest:
 
 # format data long -> wide format (one column per lab param)
 dataPlot <- subset(dataLB, PARAMCD %in% c("ALT", "AST"))
-library(reshape2)
-dataPlotWide <- dcast(
+dataPlot <- stats::aggregate(
+	LBSTRESN ~ USUBJID + VISIT + VISITNUM + PARAMCD, 
 	data = dataPlot,
-	formula = USUBJID + VISIT + VISITNUM ~ PARAMCD, 
-	value.var = "LBSTRESN",
-	fun.aggregate = mean
+	FUN = mean
 )
-
+dataPlotWide <- stats::reshape(
+	data = dataPlot,
+	timevar = "PARAMCD", idvar = c("USUBJID", "VISIT", "VISITNUM"),
+	direction = "wide"
+)
+colnames(dataPlotWide) <- sub("^LBSTRESN.", "", colnames(dataPlotWide))
 # scatterplot per visit
 scatterplotClinData(
 	data = dataPlotWide, 
@@ -78,6 +92,8 @@ scatterplotClinData(
 	caption = "Points are colored by subject ID"
 )
 
+\dontrun{
+
 # scatterplot with all visits, link subjects
 xLab <- getLabelParamcd(paramcd = "ALT", data = dataLB, 
 	paramcdVar = "PARAMCD", paramVar = "PARAM")
@@ -126,10 +142,61 @@ scatterplotClinData(
 	refLinePars = list(
 		list(slope = 1, intercept = 0, linetype = 1, color = "black", 
 			label = FALSE),
-		list(xintercept = "A1LO", linetype = 2, color = "blue"),
 		list(yintercept = "A1LO", linetype = 2, color = "blue"),
-		list(xintercept = "A1HI", linetype = 2, color = "purple"),
 		list(yintercept = "A1HI", linetype = 2, color = "purple", 
 			label = "Reference Range Upper Limit")
 	)
 )
+
+
+## scatterplot with smoothing layer
+
+data <- data.frame(
+  subj = c(rep('subj1', 20), rep('subj2', 20)),
+  time = rep( 1:20 , 2 ),
+  response =  c(1:20, 50:31) + runif(min =-3, max = +3, 40),
+  treat =  rep(c('trA', 'trB'), 20),
+  stringsAsFactors = FALSE
+)
+
+# smoothing per subject
+smoothPlot <- scatterplotClinData(
+  data = data,
+  xVar = "time", yVar = "response",
+  aesPointVar = list(color = "treat"),
+  aesLineVar = list(group = 'subj'),
+  linePars = list(linetype='dotted'),
+  aesSmoothVar = list(color='subj', group='subj'), 
+  smoothPars =  list(alpha=0.5, size=0.3 , se=TRUE, color = 'black')
+)
+smoothPlot
+
+
+# plot smoothing over subjects
+smoothPlot <- scatterplotClinData(
+  data = data,
+  xVar = "time", yVar = "response",
+  aesPointVar = list(color = "treat"),
+  aesLineVar = list(group = 'subj'),
+  linePars = list(linetype='dotted'),
+  aesSmoothVar = list(), 
+  smoothPars =  list(alpha=0.5, size=0.3 , se=TRUE, color = 'black')
+)
+smoothPlot
+
+}
+
+# add a selection box
+if(interactive()){
+  dataPlot <- subset(dataLB, PARAMCD == "ALT")
+  dataPlot$TRTA <- with(dataPlot, reorder(TRTA, TRTAN))
+  scatterplotClinData(
+    data = dataPlot, 
+    xVar = "ADY",
+    yVar = "LBSTRESN",
+    aesPointVar = list(fill = "TRTA", color = "TRTA"),
+    aesLineVar = list(group = "USUBJID", color = "TRTA"),
+    selectVars = "TRTA",
+    labelVars = labelVars
+  )
+}
